@@ -24,7 +24,7 @@ if (!missing(covar)) {
   if (!is.na(opt$nbins) & opt$nbins!=0)
       stop("if covar is set, nbins must be 0 or NA")
   if (!all(weights == as.integer(rep(1,length(y))))) 
-      stop("if covar is set, weights must not be set")
+      stop("if covar is set, weights must not be set.")
   covar.set <- TRUE
   }
 
@@ -150,7 +150,7 @@ if (model == "parallel") {
   }
 
 p <- NULL
-if (!(model == "none")) {
+if (model %in% c("equal", "parallel")) {
   if (!covar.set) {
       p   <- p.quad.moment(Q - B * obs, covar, obs,
                          sum(weights)-length(weights))
